"""
All widgets are imported into widget's namespace. This means you can access
widgets without their modules, such as ``sgc.widgets.Button``.

Widgets:
  :py:class:`Simple<base_widget.Simple>`: Simple widget that does nothing. May be useful for images etc.
  :py:class:`Button<button.Button>`: Clickable button.
  :py:class:`FPSCounter<fps_counter.FPSCounter>`: FPS counter.
  :py:class:`InputBox<input_box.InputBox>`: Input box.
  :py:class:`Label<label.Label>`: Label.
  :py:class:`Menu<menu.Menu>`: Game menu.
  :py:class:`Radio<radio_button.Radio>`: Radio button.
  :py:class:`settings`: TODO (Stay away). Common user settings (keymap etc.)
  :py:class:`Toggle<toggle.Toggle>`: Toggle button.

Container widgets:
  :py:class:`Container<container.Container>`: Basic container, holds a group of other widgets and handles
      focus between them.
  :py:class:`VBox<boxes.VBox>`: Automatically aligns widgets into a vertical column.
  :py:class:`HBox<boxes.HBox>`: Automatically aligns widgets into a horizontal row.
  :py:class:`Dialog<dialog.Dialog>`: Dialog window.
  :py:class:`ScrollBox<scroll_box.ScrollBox>`: Allows another widget to be scrollable.

"""

from . import *
from _locals import update, event
from base_widget import Simple
from boxes import VBox, HBox
from button import Button
from container import Container
from dialog import Dialog
from fps_counter import FPSCounter
from input_box import InputBox
from label import Label
from menu import Menu
from radio_button import Radio
from scroll_box import ScrollBox
from settings import Keys
from toggle import Toggle
